@@ -65,10 +65,34 @@ pub(crate) fn get_progress_message(progress_data: &ProgressData) -> String {
         CurrentStage::SimilarImagesCalculatingHashes => "Calculating image hashes",
         CurrentStage::SimilarImagesComparingHashes => "Comparing image hashes",
         CurrentStage::SimilarVideosCalculatingHashes => "Reading similar values",
+        CurrentStage::SimilarVideosCreatingThumbnails | CurrentStage::VideoOptimizerCreatingThumbnails => "Creating video thumbnails",
         CurrentStage::BrokenFilesChecking => "Checking broken files",
         CurrentStage::BadExtensionsChecking => "Checking extensions of files",
         CurrentStage::DeletingFiles => "Deleting files/folders",
-        _ => unreachable!("Unsupported stage {:?}", progress_data.sstage),
+        CurrentStage::RenamingFiles => "Renaming files",
+        CurrentStage::MovingFiles => "Moving files",
+        CurrentStage::HardlinkingFiles => "Creating hardlinks",
+        CurrentStage::SymlinkingFiles => "Creating symlinks",
+        CurrentStage::OptimizingVideos => "Optimizing videos",
+        CurrentStage::CleaningExif => "Cleaning EXIF data",
+        CurrentStage::ExifRemoverExtractingTags => "Extracting EXIF tags",
+        CurrentStage::VideoOptimizerProcessingVideos => "Processing videos",
+        CurrentStage::BadNamesChecking => "Checking names of files",
+
+        CurrentStage::CollectingFiles
+        | CurrentStage::DuplicateCacheSaving
+        | CurrentStage::DuplicateCacheLoading
+        | CurrentStage::DuplicatePreHashCacheSaving
+        | CurrentStage::DuplicatePreHashCacheLoading
+        | CurrentStage::DuplicateScanningName
+        | CurrentStage::DuplicateScanningSizeName
+        | CurrentStage::DuplicateScanningSize
+        | CurrentStage::SameMusicCacheSavingTags
+        | CurrentStage::SameMusicCacheLoadingTags
+        | CurrentStage::SameMusicCacheSavingFingerprints
+        | CurrentStage::SameMusicCacheLoadingFingerprints
+        | CurrentStage::ExifRemoverCacheLoading
+        | CurrentStage::ExifRemoverCacheSaving => unreachable!("This stages(caches, initial files scanning) should be handled somewhere else"),
     }
     .to_string()
 }
@@ -76,6 +100,7 @@ pub(crate) fn get_progress_message(progress_data: &ProgressData) -> String {
 pub(crate) fn get_progress_bar_for_collect_files() -> ProgressBar {
     let pb = ProgressBar::new_spinner();
     pb.enable_steady_tick(Duration::from_millis(120));
+    #[expect(clippy::literal_string_with_formatting_args)]
     pb.set_style(
         ProgressStyle::with_template("{msg} {spinner:.blue}")
             .expect("Failed to create progress bar style")
