@@ -1,5 +1,7 @@
 //! Helper modules: generic utilities, traits, structs, ready to copy/paste to other projects.
 
+pub mod audio_checker;
 pub mod debug_timer;
 pub mod delayed_sender;
+pub mod ffprobe;
 pub mod messages;
