@@ -1,14 +1,17 @@
 pub mod core;
+#[cfg(test)]
+mod tests;
 pub mod traits;
 mod workarounds;
 
 use std::path::{Path, PathBuf};
+use std::time::Duration;
 
 use serde::Serialize;
 
 use crate::common::model::FileEntry;
 use crate::common::tool_data::CommonToolData;
-use crate::common::traits::*;
+use crate::common::traits::ResultEntry;
 
 #[derive(Clone, Serialize, Debug)]
 pub struct BadFileEntry {
@@ -32,11 +35,15 @@ impl ResultEntry for BadFileEntry {
     }
 }
 
-#[derive(Default, Clone)]
+#[derive(Default, Clone, Copy)]
 pub struct Info {
     pub number_of_files_with_bad_extension: usize,
+    pub scanning_time: Duration,
 }
 
+#[derive(Clone, Debug, Default, Copy)]
+pub struct BadExtensionsFixParams {}
+
 #[derive(Clone)]
 pub struct BadExtensionsParameters {
     pub include_files_without_extension: bool,
