@@ -1,14 +1,13 @@
-use std::collections::{BTreeMap, HashSet};
+use std::collections::BTreeMap;
 use std::fs::File;
 use std::path::Path;
 use std::sync::Arc;
 use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
 use std::{mem, panic};
 
-use anyhow::Context;
 use crossbeam_channel::Sender;
 use fun_time::fun_time;
-use humansize::{BINARY, format_size};
+use indexmap::IndexSet;
 use lofty::file::{AudioFile, TaggedFileExt};
 use lofty::prelude::*;
 use lofty::read_from;
@@ -22,15 +21,15 @@ use symphonia::core::io::MediaSourceStream;
 use symphonia::core::meta::MetadataOptions;
 use symphonia::core::probe::Hint;
 
-use crate::common::cache::{CACHE_VERSION, extract_loaded_cache, load_cache_from_file_generalized_by_path, save_cache_to_file_generalized};
-use crate::common::consts::AUDIO_FILES_EXTENSIONS;
+use crate::common::cache::{CACHE_VERSION, load_and_split_cache_generalized_by_path, save_and_connect_cache_generalized_by_path};
 use crate::common::create_crash_message;
 use crate::common::dir_traversal::{DirTraversalBuilder, DirTraversalResult};
 use crate::common::model::{ToolType, WorkContinueStatus};
 use crate::common::progress_data::{CurrentStage, ProgressData};
 use crate::common::progress_stop_handler::{check_if_stop_received, prepare_thread_handler_common};
 use crate::common::tool_data::{CommonData, CommonToolData};
-use crate::common::traits::*;
+use crate::common::traits::ResultEntry;
+use crate::flc;
 use crate::tools::same_music::{GroupedFilesToCheck, Info, MusicEntry, MusicSimilarity, SameMusic, SameMusicParameters};
 
 impl SameMusic {
@@ -39,9 +38,9 @@ impl SameMusic {
             common_data: CommonToolData::new(ToolType::SameMusic),
             information: Info::default(),
             music_entries: Vec::with_capacity(2048),
-            duplicated_music_entries: vec![],
+            duplicated_music_entries: Vec::new(),
             music_to_check: Default::default(),
-            duplicated_music_entries_referenced: vec![],
+            duplicated_music_entries_referenced: Vec::new(),
             hash_preset_config: Configuration::preset_test1(), // TODO allow to change this and move to parameters
             params,
         }
@@ -49,11 +48,6 @@ impl SameMusic {
 
     #[fun_time(message = "check_files", level = "debug")]
     pub(crate) fn check_files(&mut self, stop_flag: &Arc<AtomicBool>, progress_sender: Option<&Sender<ProgressData>>) -> WorkContinueStatus {
-        self.common_data.extensions.set_and_validate_allowed_extensions(AUDIO_FILES_EXTENSIONS);
-        if !self.common_data.extensions.set_any_extensions() {
-            return WorkContinueStatus::Continue;
-        }
-
         let result = DirTraversalBuilder::new()
             .group_by(|_fe| ())
             .stop_flag(stop_flag)
@@ -81,52 +75,12 @@ impl SameMusic {
 
     #[fun_time(message = "load_cache", level = "debug")]
     fn load_cache(&mut self, checking_tags: bool) -> (BTreeMap<String, MusicEntry>, BTreeMap<String, MusicEntry>, BTreeMap<String, MusicEntry>) {
-        let loaded_hash_map;
-
-        let mut records_already_cached: BTreeMap<String, MusicEntry> = Default::default();
-        let mut non_cached_files_to_check: BTreeMap<String, MusicEntry> = Default::default();
-
-        if self.common_data.use_cache {
-            let (messages, loaded_items) =
-                load_cache_from_file_generalized_by_path::<MusicEntry>(&get_similar_music_cache_file(checking_tags), self.get_delete_outdated_cache(), &self.music_to_check);
-            self.get_text_messages_mut().extend_with_another_messages(messages);
-            loaded_hash_map = loaded_items.unwrap_or_default();
-
-            debug!("load_cache - Starting to check for differences");
-            extract_loaded_cache(
-                &loaded_hash_map,
-                mem::take(&mut self.music_to_check),
-                &mut records_already_cached,
-                &mut non_cached_files_to_check,
-            );
-            debug!(
-                "load_cache - completed diff between loaded and prechecked files, {}({}) - non cached, {}({}) - already cached",
-                non_cached_files_to_check.len(),
-                format_size(non_cached_files_to_check.values().map(|e| e.size).sum::<u64>(), BINARY),
-                records_already_cached.len(),
-                format_size(records_already_cached.values().map(|e| e.size).sum::<u64>(), BINARY),
-            );
-        } else {
-            loaded_hash_map = Default::default();
-            mem::swap(&mut self.music_to_check, &mut non_cached_files_to_check);
-        }
-        (loaded_hash_map, records_already_cached, non_cached_files_to_check)
+        load_and_split_cache_generalized_by_path(&get_similar_music_cache_file(checking_tags), mem::take(&mut self.music_to_check), self)
     }
 
     #[fun_time(message = "save_cache", level = "debug")]
-    fn save_cache(&mut self, vec_file_entry: Vec<MusicEntry>, loaded_hash_map: BTreeMap<String, MusicEntry>, checking_tags: bool) {
-        if !self.common_data.use_cache {
-            return;
-        }
-        // Must save all results to file, old loaded from file with all currently counted results
-        let mut all_results: BTreeMap<String, MusicEntry> = loaded_hash_map;
-
-        for file_entry in vec_file_entry {
-            all_results.insert(file_entry.path.to_string_lossy().to_string(), file_entry);
-        }
-
-        let messages = save_cache_to_file_generalized(&get_similar_music_cache_file(checking_tags), &all_results, self.common_data.save_also_as_json, 0);
-        self.get_text_messages_mut().extend_with_another_messages(messages);
+    fn save_cache(&mut self, vec_file_entry: &[MusicEntry], loaded_hash_map: BTreeMap<String, MusicEntry>, checking_tags: bool) {
+        save_and_connect_cache_generalized_by_path(&get_similar_music_cache_file(checking_tags), vec_file_entry, loaded_hash_map, self);
     }
 
     #[fun_time(message = "calculate_fingerprint", level = "debug")]
@@ -197,16 +151,14 @@ impl SameMusic {
         debug!("calculate_fingerprint - ended fingerprinting");
 
         progress_handler.join_thread();
+
         let progress_handler = prepare_thread_handler_common(progress_sender, CurrentStage::SameMusicCacheSavingFingerprints, 0, self.get_test_type(), 0);
 
-        // Just connect loaded results with already calculated
         vec_file_entry.extend(records_already_cached.into_values());
 
-        self.music_entries = vec_file_entry.clone();
+        self.save_cache(&vec_file_entry, loaded_hash_map, false);
 
-        self.save_cache(vec_file_entry, loaded_hash_map, false);
-
-        // Break if stop was clicked after saving to cache
+        self.music_entries = vec_file_entry;
 
         progress_handler.join_thread();
         if check_if_stop_received(stop_flag) {
@@ -259,14 +211,11 @@ impl SameMusic {
         progress_handler.join_thread();
         let progress_handler = prepare_thread_handler_common(progress_sender, CurrentStage::SameMusicCacheSavingTags, 0, self.get_test_type(), 0);
 
-        // Just connect loaded results with already calculated
         vec_file_entry.extend(records_already_cached.into_values());
 
-        self.music_entries = vec_file_entry.clone();
+        self.save_cache(&vec_file_entry, loaded_hash_map, true);
 
-        self.save_cache(vec_file_entry, loaded_hash_map, true);
-
-        // Break if stop was clicked after saving to cache
+        self.music_entries = vec_file_entry;
 
         progress_handler.join_thread();
         if check_if_stop_received(stop_flag) {
@@ -292,7 +241,12 @@ impl SameMusic {
                 return WorkContinueStatus::Stop;
             }
 
-            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| &fe.track_title, self.params.approximate_comparison);
+            old_duplicates = self.check_music_item(
+                old_duplicates,
+                progress_handler.items_counter(),
+                |fe| fe.track_title.clone(),
+                self.params.approximate_comparison,
+            );
         }
         if (self.params.music_similarity & MusicSimilarity::TRACK_ARTIST) == MusicSimilarity::TRACK_ARTIST {
             if check_if_stop_received(stop_flag) {
@@ -300,7 +254,12 @@ impl SameMusic {
                 return WorkContinueStatus::Stop;
             }
 
-            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| &fe.track_artist, self.params.approximate_comparison);
+            old_duplicates = self.check_music_item(
+                old_duplicates,
+                progress_handler.items_counter(),
+                |fe| fe.track_artist.clone(),
+                self.params.approximate_comparison,
+            );
         }
         if (self.params.music_similarity & MusicSimilarity::YEAR) == MusicSimilarity::YEAR {
             if check_if_stop_received(stop_flag) {
@@ -308,7 +267,7 @@ impl SameMusic {
                 return WorkContinueStatus::Stop;
             }
 
-            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| &fe.year, false);
+            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| fe.year.clone(), false);
         }
         if (self.params.music_similarity & MusicSimilarity::LENGTH) == MusicSimilarity::LENGTH {
             if check_if_stop_received(stop_flag) {
@@ -316,7 +275,7 @@ impl SameMusic {
                 return WorkContinueStatus::Stop;
             }
 
-            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| &fe.length, false);
+            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| format_audio_duration(fe.length), false);
         }
         if (self.params.music_similarity & MusicSimilarity::GENRE) == MusicSimilarity::GENRE {
             if check_if_stop_received(stop_flag) {
@@ -324,7 +283,7 @@ impl SameMusic {
                 return WorkContinueStatus::Stop;
             }
 
-            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| &fe.genre, false);
+            old_duplicates = self.check_music_item(old_duplicates, progress_handler.items_counter(), |fe| fe.genre.clone(), false);
         }
         if (self.params.music_similarity & MusicSimilarity::BITRATE) == MusicSimilarity::BITRATE {
             if check_if_stop_received(stop_flag) {
@@ -337,9 +296,8 @@ impl SameMusic {
                 for file_entry in vec_file_entry {
                     if file_entry.bitrate != 0 {
                         let thing = file_entry.bitrate.to_string();
-                        if !thing.is_empty() {
-                            hash_map.entry(thing.clone()).or_default().push(file_entry);
-                        }
+
+                        hash_map.entry(thing).or_default().push(file_entry);
                     }
                 }
                 for (_title, vec_file_entry) in hash_map {
@@ -411,6 +369,7 @@ impl SameMusic {
                     // When there is 0 files in base files or files to compare there will be no comparison, so removing it from the list
                     // Also when there is only one file in base files and files to compare and they are the same file, there will be no comparison
 
+                    #[expect(clippy::indexing_slicing)] // Validated that base_files/files_to_compare are not empty
                     if base_files.is_empty()
                         || files_to_compare.is_empty()
                         || (base_files.len() == 1 && files_to_compare.len() == 1 && (base_files[0].path == files_to_compare[0].path))
@@ -436,7 +395,7 @@ impl SameMusic {
         base_files: Vec<MusicEntry>,
         files_to_compare: &[MusicEntry],
     ) -> Option<Vec<Vec<MusicEntry>>> {
-        let mut used_paths: HashSet<String> = Default::default();
+        let mut used_paths: IndexSet<String> = Default::default();
 
         let configuration = &self.hash_preset_config;
         let minimum_segment_duration = self.params.minimum_segment_duration;
@@ -464,7 +423,7 @@ impl SameMusic {
                     }
                     let mut segments = match match_fingerprints(&f_entry.fingerprint, &e_entry.fingerprint, configuration) {
                         Ok(segments) => segments,
-                        Err(e) => return Some(Err(format!("Error while comparing fingerprints: {e}"))),
+                        Err(e) => return Some(Err(flc!("core_error_comparing_fingerprints", reason = e.to_string()))),
                     };
                     segments.retain(|s| s.duration(configuration) > minimum_segment_duration && s.score < maximum_difference);
                     if segments.is_empty() { None } else { Some(Ok((e_string, e_entry))) }
@@ -544,7 +503,7 @@ impl SameMusic {
         &self,
         old_duplicates: Vec<Vec<MusicEntry>>,
         items_counter: &Arc<AtomicUsize>,
-        get_item: fn(&MusicEntry) -> &str,
+        get_item: fn(&MusicEntry) -> String,
         approximate_comparison: bool,
     ) -> Vec<Vec<MusicEntry>> {
         let mut new_duplicates: Vec<_> = Default::default();
@@ -573,12 +532,12 @@ impl SameMusic {
 }
 
 // TODO this should be taken from rusty-chromaprint repo, not reimplemented here
-fn calc_fingerprint_helper(path: impl AsRef<Path>, config: &Configuration) -> anyhow::Result<Vec<u32>> {
+fn calc_fingerprint_helper<P: AsRef<Path>>(path: P, config: &Configuration) -> Result<Vec<u32>, String> {
     let path = path.as_ref().to_path_buf();
     panic::catch_unwind(|| {
         let path = &path;
 
-        let src = File::open(path).context("failed to open file")?;
+        let src = File::open(path).map_err(|_| "failed to open file".to_string())?;
         let mss = MediaSourceStream::new(Box::new(src), Default::default());
 
         let mut hint = Hint::new();
@@ -589,7 +548,9 @@ fn calc_fingerprint_helper(path: impl AsRef<Path>, config: &Configuration) -> an
         let meta_opts: MetadataOptions = Default::default();
         let fmt_opts: FormatOptions = Default::default();
 
-        let probed = symphonia::default::get_probe().format(&hint, mss, &fmt_opts, &meta_opts).context("unsupported format")?;
+        let probed = symphonia::default::get_probe()
+            .format(&hint, mss, &fmt_opts, &meta_opts)
+            .map_err(|_| "unsupported format".to_string())?;
 
         let mut format = probed.format;
 
@@ -597,18 +558,20 @@ fn calc_fingerprint_helper(path: impl AsRef<Path>, config: &Configuration) -> an
             .tracks()
             .iter()
             .find(|t| t.codec_params.codec != CODEC_TYPE_NULL)
-            .context("no supported audio tracks")?;
+            .ok_or_else(|| "no supported audio tracks".to_string())?;
 
         let dec_opts: DecoderOptions = Default::default();
 
-        let mut decoder = symphonia::default::get_codecs().make(&track.codec_params, &dec_opts).context("unsupported codec")?;
+        let mut decoder = symphonia::default::get_codecs()
+            .make(&track.codec_params, &dec_opts)
+            .map_err(|_| "unsupported codec".to_string())?;
 
         let track_id = track.id;
 
         let mut printer = Fingerprinter::new(config);
-        let sample_rate = track.codec_params.sample_rate.context("missing sample rate")?;
-        let channels = track.codec_params.channels.context("missing audio channels")?.count() as u32;
-        printer.start(sample_rate, channels).context("initializing fingerprinter")?;
+        let sample_rate = track.codec_params.sample_rate.ok_or_else(|| "missing sample rate".to_string())?;
+        let channels = track.codec_params.channels.ok_or_else(|| "missing audio channels".to_string())?.count() as u32;
+        printer.start(sample_rate, channels).map_err(|_| "initializing fingerprinter".to_string())?;
 
         let mut sample_buf = None;
 
@@ -645,7 +608,7 @@ fn calc_fingerprint_helper(path: impl AsRef<Path>, config: &Configuration) -> an
     .unwrap_or_else(|_| {
         let message = create_crash_message("Symphonia", &path.to_string_lossy(), "https://github.com/pdeljanov/Symphonia");
         error!("{message}");
-        Err(anyhow::anyhow!("{message}"))
+        Err(message)
     })
 }
 
@@ -670,64 +633,66 @@ fn read_single_file_tags(path: &str, mut music_entry: MusicEntry) -> Option<Musi
     let mut genre = String::new();
 
     let bitrate = properties.audio_bitrate().unwrap_or(0);
-    let mut length = properties.duration().as_millis().to_string();
 
     if let Some(tag) = tagged_file.primary_tag() {
-        track_title = tag.get_string(&ItemKey::TrackTitle).unwrap_or_default().to_string();
-        track_artist = tag.get_string(&ItemKey::TrackArtist).unwrap_or_default().to_string();
-        year = tag.get_string(&ItemKey::Year).unwrap_or_default().to_string();
-        genre = tag.get_string(&ItemKey::Genre).unwrap_or_default().to_string();
+        track_title = tag.get_string(ItemKey::TrackTitle).unwrap_or_default().to_string();
+        track_artist = tag.get_string(ItemKey::TrackArtist).unwrap_or_default().to_string();
+        year = tag.get_string(ItemKey::Year).unwrap_or_default().to_string();
+        genre = tag.get_string(ItemKey::Genre).unwrap_or_default().to_string();
     }
 
     for tag in tagged_file.tags() {
-        if track_title.is_empty() {
-            if let Some(tag_value) = tag.get_string(&ItemKey::TrackTitle) {
-                track_title = tag_value.to_string();
-            }
+        if track_title.is_empty()
+            && let Some(tag_value) = tag.get_string(ItemKey::TrackTitle)
+        {
+            track_title = tag_value.to_string();
         }
-        if track_artist.is_empty() {
-            if let Some(tag_value) = tag.get_string(&ItemKey::TrackArtist) {
-                track_artist = tag_value.to_string();
-            }
+        if track_artist.is_empty()
+            && let Some(tag_value) = tag.get_string(ItemKey::TrackArtist)
+        {
+            track_artist = tag_value.to_string();
         }
-        if year.is_empty() {
-            if let Some(tag_value) = tag.get_string(&ItemKey::Year) {
-                year = tag_value.to_string();
-            }
+        if year.is_empty()
+            && let Some(tag_value) = tag.get_string(ItemKey::Year)
+        {
+            year = tag_value.to_string();
         }
-        if genre.is_empty() {
-            if let Some(tag_value) = tag.get_string(&ItemKey::Genre) {
-                genre = tag_value.to_string();
-            }
+        if genre.is_empty()
+            && let Some(tag_value) = tag.get_string(ItemKey::Genre)
+        {
+            genre = tag_value.to_string();
         }
     }
 
-    if let Ok(old_length_number) = length.parse::<u32>() {
-        let length_number = old_length_number / 60;
-        let minutes = length_number / 1000;
-        let seconds = (length_number % 1000) * 6 / 100;
-        if minutes != 0 || seconds != 0 {
-            length = format!("{minutes}:{seconds:02}");
-        } else if old_length_number > 0 {
-            // That means, that audio have length smaller that second but not zero
-            length = "0:01".to_string();
-        } else {
-            length = String::new();
-        }
+    let length_milliseconds = properties.duration().as_millis();
+    let length_in_seconds = if length_milliseconds == 0 {
+        0
     } else {
-        length = String::new();
-    }
+        let secs = properties.duration().as_secs() as u32;
+        if secs == 0 { 1 } else { secs }
+    };
 
     music_entry.track_title = track_title;
     music_entry.track_artist = track_artist;
     music_entry.year = year;
-    music_entry.length = length;
+    music_entry.length = length_in_seconds;
     music_entry.genre = genre;
     music_entry.bitrate = bitrate;
 
     Some(music_entry)
 }
 
+pub fn format_audio_duration(duration: u32) -> String {
+    let hours = duration / 3600;
+    let minutes = (duration % 3600) / 60;
+    let seconds = duration % 60;
+    if hours > 0 {
+        format!("{hours}:{minutes:02}:{seconds:02}")
+    } else {
+        format!("{minutes}:{seconds:02}")
+    }
+}
+
 fn get_simplified_name_internal(what: &str, ignore_numbers: bool) -> String {
     let mut new_what = String::with_capacity(what.len());
     let mut tab_number = 0;
