@@ -1,6 +1,6 @@
 use crate::gui_structs::gui_data::GuiData;
-use crate::help_functions::*;
-use crate::notebook_enums::*;
+use crate::help_functions::set_buttons;
+use crate::notebook_enums::to_notebook_main_enum;
 
 pub(crate) fn connect_notebook_tabs(gui_data: &GuiData) {
     let shared_buttons = gui_data.shared_buttons.clone();
