@@ -7,7 +7,7 @@ use crate::help_combo_box::IMAGES_HASH_SIZE_COMBO_BOX;
 
 pub(crate) fn connect_similar_image_size_change(gui_data: &GuiData) {
     let label_similar_images_minimal_similarity = gui_data.main_notebook.label_similar_images_minimal_similarity.clone();
-    label_similar_images_minimal_similarity.set_text(&get_string_from_similarity(&SIMILAR_VALUES[0][5], 8));
+    label_similar_images_minimal_similarity.set_text(&get_string_from_similarity(SIMILAR_VALUES[0][5], 8));
 
     let combo_box_image_hash_size = gui_data.main_notebook.combo_box_image_hash_size.clone();
     let label_similar_images_minimal_similarity = gui_data.main_notebook.label_similar_images_minimal_similarity.clone();
@@ -26,6 +26,6 @@ pub(crate) fn connect_similar_image_size_change(gui_data: &GuiData) {
 
         scale_similarity_similar_images.set_range(0_f64, SIMILAR_VALUES[index][5] as f64);
         scale_similarity_similar_images.set_fill_level(SIMILAR_VALUES[index][5] as f64);
-        label_similar_images_minimal_similarity.set_text(&get_string_from_similarity(&SIMILAR_VALUES[index][5], hash_size as u8));
+        label_similar_images_minimal_similarity.set_text(&get_string_from_similarity(SIMILAR_VALUES[index][5], hash_size as u8));
     });
 }
