@@ -8,6 +8,8 @@ pub struct GuiSelectPopovers {
     pub buttons_popover_select_all: gtk4::Button,
     pub buttons_popover_unselect_all: gtk4::Button,
     pub buttons_popover_reverse: gtk4::Button,
+    pub buttons_popover_select_all_except_shortest_path: gtk4::Button,
+    pub buttons_popover_select_all_except_longest_path: gtk4::Button,
     pub buttons_popover_select_all_except_oldest: gtk4::Button,
     pub buttons_popover_select_all_except_newest: gtk4::Button,
     pub buttons_popover_select_one_oldest: gtk4::Button,
@@ -21,14 +23,15 @@ pub struct GuiSelectPopovers {
     pub separator_select_reverse: gtk4::Separator,
     pub separator_select_date: gtk4::Separator,
     pub separator_select_custom: gtk4::Separator,
+    pub separator_select_shortest_path: gtk4::Separator,
 
-    #[allow(unused)]
+    #[expect(unused)]
     pub buttons_popover_right_click_open_file: gtk4::Button,
-    #[allow(unused)]
+    #[expect(unused)]
     pub buttons_popover_right_click_open_folder: gtk4::Button,
 
     pub popover_select: gtk4::Popover,
-    #[allow(unused)]
+    #[expect(unused)]
     pub popover_right_click: gtk4::Popover,
 }
 
@@ -40,6 +43,8 @@ impl GuiSelectPopovers {
         let buttons_popover_select_all: gtk4::Button = builder.object("buttons_popover_select_all").expect("Cambalache");
         let buttons_popover_unselect_all: gtk4::Button = builder.object("buttons_popover_unselect_all").expect("Cambalache");
         let buttons_popover_reverse: gtk4::Button = builder.object("buttons_popover_reverse").expect("Cambalache");
+        let buttons_popover_select_all_except_shortest_path: gtk4::Button = builder.object("buttons_popover_select_all_except_shortest_path").expect("Cambalache");
+        let buttons_popover_select_all_except_longest_path: gtk4::Button = builder.object("buttons_popover_select_all_except_longest_path").expect("Cambalache");
         let buttons_popover_select_all_except_oldest: gtk4::Button = builder.object("buttons_popover_select_all_except_oldest").expect("Cambalache");
         let buttons_popover_select_all_except_newest: gtk4::Button = builder.object("buttons_popover_select_all_except_newest").expect("Cambalache");
         let buttons_popover_select_one_oldest: gtk4::Button = builder.object("buttons_popover_select_one_oldest").expect("Cambalache");
@@ -53,6 +58,7 @@ impl GuiSelectPopovers {
         let separator_select_reverse: gtk4::Separator = builder.object("separator_select_reverse").expect("Cambalache");
         let separator_select_date: gtk4::Separator = builder.object("separator_select_date").expect("Cambalache");
         let separator_select_custom: gtk4::Separator = builder.object("separator_select_custom").expect("Cambalache");
+        let separator_select_shortest_path: gtk4::Separator = builder.object("separator_select_shortest_path").expect("Cambalache");
 
         let popover_select: gtk4::Popover = builder.object("popover_select").expect("Cambalache");
 
@@ -69,6 +75,8 @@ impl GuiSelectPopovers {
             buttons_popover_select_all,
             buttons_popover_unselect_all,
             buttons_popover_reverse,
+            buttons_popover_select_all_except_shortest_path,
+            buttons_popover_select_all_except_longest_path,
             buttons_popover_select_all_except_oldest,
             buttons_popover_select_all_except_newest,
             buttons_popover_select_one_oldest,
@@ -81,6 +89,7 @@ impl GuiSelectPopovers {
             separator_select_reverse,
             separator_select_date,
             separator_select_custom,
+            separator_select_shortest_path,
             buttons_popover_right_click_open_file,
             buttons_popover_right_click_open_folder,
             popover_select,
@@ -91,6 +100,10 @@ impl GuiSelectPopovers {
         self.buttons_popover_select_all.set_label(&flg!("popover_select_all"));
         self.buttons_popover_unselect_all.set_label(&flg!("popover_unselect_all"));
         self.buttons_popover_reverse.set_label(&flg!("popover_reverse"));
+        self.buttons_popover_select_all_except_shortest_path
+            .set_label(&flg!("popover_select_all_except_shortest_path"));
+        self.buttons_popover_select_all_except_longest_path
+            .set_label(&flg!("popover_select_all_except_longest_path"));
         self.buttons_popover_select_all_except_oldest.set_label(&flg!("popover_select_all_except_oldest"));
         self.buttons_popover_select_all_except_newest.set_label(&flg!("popover_select_all_except_newest"));
         self.buttons_popover_select_one_oldest.set_label(&flg!("popover_select_one_oldest"));
