@@ -1,13 +1,12 @@
 use i18n_embed::fluent::{FluentLanguageLoader, fluent_language_loader};
 use i18n_embed::{DefaultLocalizer, LanguageLoader, Localizer};
-use once_cell::sync::Lazy;
 use rust_embed::RustEmbed;
 
 #[derive(RustEmbed)]
 #[folder = "i18n/"]
 struct Localizations;
 
-pub static LANGUAGE_LOADER_GUI: Lazy<FluentLanguageLoader> = Lazy::new(|| {
+pub static LANGUAGE_LOADER_GUI: std::sync::LazyLock<FluentLanguageLoader> = std::sync::LazyLock::new(|| {
     let loader: FluentLanguageLoader = fluent_language_loader!();
 
     loader.load_fallback_language(&Localizations).expect("Error while loading fallback language");
@@ -17,12 +16,8 @@ pub static LANGUAGE_LOADER_GUI: Lazy<FluentLanguageLoader> = Lazy::new(|| {
 
 #[macro_export]
 macro_rules! flg {
-    ($message_id:literal) => {{
-        i18n_embed_fl::fl!($crate::localizer_gui::LANGUAGE_LOADER_GUI, $message_id)
-    }};
-
-    ($message_id:literal, $($args:expr),*) => {{
-        i18n_embed_fl::fl!($crate::localizer_gui::LANGUAGE_LOADER_GUI, $message_id, $($args), *)
+    ( $($tt:tt)* ) => {{
+        i18n_embed_fl::fl!($crate::localizer_gui::LANGUAGE_LOADER_GUI, $($tt)*)
     }};
 }
 
