@@ -16,7 +16,7 @@ use crate::connect_translation::{LANGUAGE_LIST, find_the_closest_language_idx_to
 use crate::settings::combo_box::StringComboBoxItem;
 
 pub const DEFAULT_MINIMUM_SIZE_KB: i32 = 16;
-pub const DEFAULT_MAXIMUM_SIZE_KB: i32 = i32::MAX / 1024;
+pub const DEFAULT_MAXIMUM_SIZE_KB: i32 = i32::MAX;
 pub const DEFAULT_MINIMUM_CACHE_SIZE: i32 = 256;
 pub const DEFAULT_MINIMUM_PREHASH_CACHE_SIZE: i32 = 256;
 pub const DEFAULT_BIGGEST_FILES: i32 = 50;
